@@ -1,6 +1,7 @@
 
 (define-module (theme-d runtime theme-d-guile-3-support)
-  #:export (theme-call-with-prompt))
+  #:export (theme-call-with-prompt
+	    theme-get-rte))
 
 (import (rnrs))
 (import (theme-d runtime runtime-theme-d-environment))
@@ -14,3 +15,6 @@
 		       handler (list _ h v)
 		       (list _b_<object> _b_<object> _b_<object>)))))
  
+(define (theme-get-rte exc)
+  (let ((proc (exception-accessor &theme-d-condition (lambda (x) x))))
+    (proc exc)))
