@@ -1,5 +1,5 @@
 
-;; Copyright (C) 2008-2019 Tommi Höynälänmaa
+;; Copyright (C) 2008-2019, 2022 Tommi Höynälänmaa
 ;; Distributed under GNU Lesser General Public License version 3,
 ;; see file doc/LGPL-3.
 
@@ -381,7 +381,8 @@
 	(is-integer? data)
 	(string? data)
 	(char? data)
-	(null? data))
+	(null? data)
+	(keyword? data))
     #t)
    ((vector? data)
     (raise
